summaryrefslogtreecommitdiffstats
path: root/ksystemlog/src/detailDialog.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 08:42:58 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 08:42:58 +0000
commit9902f14bc9162d7b286b3f99b27989237db9f264 (patch)
treeb95be3be1992566418b2c2e2ed16bdb29453a8d4 /ksystemlog/src/detailDialog.cpp
parent437249c71459e9ea15be70788687cb8695e249c2 (diff)
downloadksystemlog-9902f14bc9162d7b286b3f99b27989237db9f264.tar.gz
ksystemlog-9902f14bc9162d7b286b3f99b27989237db9f264.zip
TQt4 port ksystemlog
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ksystemlog@1239000 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksystemlog/src/detailDialog.cpp')
-rw-r--r--ksystemlog/src/detailDialog.cpp94
1 files changed, 47 insertions, 47 deletions
diff --git a/ksystemlog/src/detailDialog.cpp b/ksystemlog/src/detailDialog.cpp
index 200e73b..f232b78 100644
--- a/ksystemlog/src/detailDialog.cpp
+++ b/ksystemlog/src/detailDialog.cpp
@@ -18,10 +18,10 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-//Qt includes
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+//TQt includes
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
//KDE includes
#include <kstdguiitem.h>
@@ -36,88 +36,88 @@
#include "detailDialog.h"
-DetailDialog::DetailDialog(View* v, QWidget *parent, const char *name) :
- //KDialogBase(parent, name, false, i18n("Log Line Details"), 0 /*KDialogBase::Ok*/),
- DetailDialogBase(parent, name, false, 0),
+DetailDialog::DetailDialog(View* v, TQWidget *tqparent, const char *name) :
+ //KDialogBase(tqparent, name, false, i18n("Log Line Details"), 0 /*KDialogBase::Ok*/),
+ DetailDialogBase(tqparent, name, false, 0),
view(v),
currentLine(NULL) {
previous->setText(i18n("&Previous"));
- connect(previous, SIGNAL(clicked()), this, SLOT(previousItem()));
+ connect(previous, TQT_SIGNAL(clicked()), this, TQT_SLOT(previousItem()));
next->setText(i18n("&Next"));
- connect(next, SIGNAL(clicked()), this, SLOT(nextItem()));
+ connect(next, TQT_SIGNAL(clicked()), this, TQT_SLOT(nextItem()));
//close->setText(KStdGuiItem::close().text());
//close->setIcon(KStdGuiItem::close().iconSet());
- connect(closeButton, SIGNAL(clicked()), this, SLOT(closeDetails()));
+ connect(closeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(closeDetails()));
updateDetails();
/* This code has been replaced by a pretty drawing of the Detail Dialog with Qt Designer
setMinimumHeight(200);
setMinimumWidth(450);
- QWhatsThis::add(this, i18n("This dialog displays detailed information about the currently selected log line."));
+ TQWhatsThis::add(this, i18n("This dialog displays detailed information about the currently selected log line."));
- QWidget* widget=new QWidget(this);
+ TQWidget* widget=new TQWidget(this);
- QVBoxLayout* mainLayout = new QVBoxLayout(widget, 0, 10);
+ TQVBoxLayout* mainLayout = new TQVBoxLayout(widget, 0, 10);
- QHBoxLayout* l1 = new QHBoxLayout(0, 0, 5);
+ TQHBoxLayout* l1 = new TQHBoxLayout(0, 0, 5);
- icon=new QLabel(widget);
- //icon->setSizePolicy( QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum ) );
- l1->addWidget(icon, 0, Qt::AlignVCenter);
+ icon=new TQLabel(widget);
+ //icon->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+ l1->addWidget(icon, 0, TQt::AlignVCenter);
//header=new KActiveLabel(widget, "header");
- header=new QLabel(widget, "header");
- //header->setSizePolicy( QSizePolicy( QSizePolicy::Maximum, QSizePolicy::Minimum) );
- //header->setSizePolicy( QSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Minimum ) );
- l1->addWidget(header, 0, Qt::AlignVCenter || Qt::AlignHCenter);
+ header=new TQLabel(widget, "header");
+ //header->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Minimum) );
+ //header->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::Minimum ) );
+ l1->addWidget(header, 0, TQt::AlignVCenter || TQt::AlignHCenter);
mainLayout->addLayout(l1);
- message=new QTextEdit(widget);
+ message=new TQTextEdit(widget);
message->setReadOnly(true);
- //message->setSizePolicy( QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum) );
- //message->setSizePolicy( QSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding ) );
+ //message->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum) );
+ //message->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding ) );
//message->setMinimumHeight(40);
//message->setMinimumHeight(60);
//message->setMinimumWidth(400);
mainLayout->addWidget(message);
- QHBoxLayout* buttons=new QHBoxLayout(0, 0, 10);
+ TQHBoxLayout* buttons=new TQHBoxLayout(0, 0, 10);
- previous=new QPushButton(KStdGuiItem::back().iconSet(), i18n("&Previous"), widget);
- connect(previous, SIGNAL(clicked()), this, SLOT(previousItem()));
- //1=Stretch factor (ratio between object in the QHBoxLayout)
- buttons->addWidget(previous, 1, Qt::AlignRight);
+ previous=new TQPushButton(KStdGuiItem::back().iconSet(), i18n("&Previous"), widget);
+ connect(previous, TQT_SIGNAL(clicked()), this, TQT_SLOT(previousItem()));
+ //1=Stretch factor (ratio between object in the TQHBoxLayout)
+ buttons->addWidget(previous, 1, TQt::AlignRight);
- QToolTip::add(previous, i18n("Move to the previous line"));
- QWhatsThis::add(previous, i18n("Moves to the previous line. This button is deactivated if there is no previous log line."));
+ TQToolTip::add(previous, i18n("Move to the previous line"));
+ TQWhatsThis::add(previous, i18n("Moves to the previous line. This button is deactivated if there is no previous log line."));
buttons->setStretchFactor(previous, 1);
- next=new QPushButton(KStdGuiItem::forward().iconSet(), i18n("&Next"), widget);
- connect(next, SIGNAL(clicked()), this, SLOT(nextItem()));
- //1=Stretch factor (ratio between object in the QHBoxLayout)
- buttons->addWidget(next, 1, Qt::AlignLeft);
+ next=new TQPushButton(KStdGuiItem::forward().iconSet(), i18n("&Next"), widget);
+ connect(next, TQT_SIGNAL(clicked()), this, TQT_SLOT(nextItem()));
+ //1=Stretch factor (ratio between object in the TQHBoxLayout)
+ buttons->addWidget(next, 1, TQt::AlignLeft);
- QToolTip::add(next, i18n("Move to the next line"));
- QWhatsThis::add(next, i18n("Moves to the next line. This button is deactivated if there is no next log line."));
+ TQToolTip::add(next, i18n("Move to the next line"));
+ TQWhatsThis::add(next, i18n("Moves to the next line. This button is deactivated if there is no next log line."));
- QPushButton* close=new QPushButton(KStdGuiItem::close().iconSet(), KStdGuiItem::close().text(), widget);
- connect(close, SIGNAL(clicked()), this, SLOT(closeDetails()));
- buttons->addWidget(close, 0, Qt::AlignRight);
+ TQPushButton* close=new TQPushButton(KStdGuiItem::close().iconSet(), KStdGuiItem::close().text(), widget);
+ connect(close, TQT_SIGNAL(clicked()), this, TQT_SLOT(closeDetails()));
+ buttons->addWidget(close, 0, TQt::AlignRight);
- QToolTip::add(next, i18n("Close the Detail dialog."));
- QWhatsThis::add(next, i18n("Closes this Detail dialog."));
+ TQToolTip::add(next, i18n("Close the Detail dialog."));
+ TQWhatsThis::add(next, i18n("Closes this Detail dialog."));
mainLayout->addLayout(buttons);
@@ -205,10 +205,10 @@ void DetailDialog::previousItem() {
}
currentLine->setSelected(false);
- currentLine->repaint();
+ currentLine->tqrepaint();
currentLine=static_cast<LogListItem*> (currentLine->itemAbove());
currentLine->setSelected(true);
- currentLine->repaint();
+ currentLine->tqrepaint();
updateDetails();
@@ -230,10 +230,10 @@ void DetailDialog::nextItem() {
}
currentLine->setSelected(false);
- currentLine->repaint();
+ currentLine->tqrepaint();
currentLine=static_cast<LogListItem*> (currentLine->itemBelow());
currentLine->setSelected(true);
- currentLine->repaint();
+ currentLine->tqrepaint();
updateDetails();
@@ -36,88 +36,88 @@
updateDetails();
- /* This code has been replaced by a pretty drawing of the Detail Dialog with Qt Designer
+ /* This code has been replaced by a pretty drawing of the Detail Dialog with TQt Designer
setMinimumHeight(200);
setMinimumWidth(450);